<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Customizer\Configs\Footer
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		3.5
 * @version		3.7.3
 */

namespace WeCodeArt\Customizer\Configs;

if ( ! defined( 'ABSPATH' ) ) exit;

use WeCodeArt\Customizer\Config;
use WeCodeArt\Customizer\Formatting;

/**
 * Customizer Config Footer setup
 */
class Footer extends Config {
	/**
	 * Register Site Layout Customizer Configurations
	 *
	 * @param 	array                $configurations 
	 * @param 	WP_Customize_Manager $wp_customize instance of WP_Customize_Manager.
	 * @since 	3.6
	 *
	 * @return 	array 
	 */
	public function register( $configurations, $wp_customize ) {
		// A handy class for formatting theme mods.
		$formatting = Formatting::get_instance();

		// Header Modules Choices.
		$widgets = array();
		$modules = \WeCodeArt\Core\Footer::footer_widgets();
		foreach( $modules as $k => $v ) $widgets[$k] = $v['label']; 

		$_configs = array( 
			array(
				'name'			=> 'footer-layout-container',
				'type' 			=> 'control',
				'control'  		=> 'select',
				'section'		=> 'footer-layout',
				'title' 		=> esc_html__( 'Grid Type', 'wecodeart' ),
				'description' 	=> esc_html__( 'Choose the type of the container class.', 'wecodeart' ),
				'choices'  		=> [
					'container'			=> esc_html__( 'Container', 'wecodeart' ),
					'container-fluid' 	=> esc_html__( 'Container Fluid', 'wecodeart' ),
				], 
				'priority' 		=> 5, 
				'sanitize_callback'    => [ $formatting, 'sanitize_choices' ], 
				'transport' 		   => 'postMessage'
			),
			array(
				'name'			=> 'footer-layout-modules',
				'type'        	=> 'control',
				'control'  		=> 'wecodeart-sortable',
				'section'		=> 'footer-layout',
				'title'			=> esc_html__( 'Footer Columns', 'wecodeart' ),
				'description'	=> esc_html__( 'Enable and reorder Footer Columns.', 'wecodeart' ),
				'priority'   	=> 10, 
				'choices'		=> $widgets,
				'transport'		=> 'postMessage',
				'partial'		=> [
					'selector'        => '.footer__widgets',
					'render_callback' => [ 'WeCodeArt\Core\Footer', 'render_widgets' ],
					'container_inclusive' => true
				]
			),
			array(
				'name'			=> 'footer-copyright-text',
				'type'        	=> 'control',
				'control'  		=> 'textarea',
				'section'		=> 'footer-copyright',
				'title'			=> esc_html__( 'Footer Copyright Text', 'wecodeart' ),
				'description'	=> esc_html__( 'Enter your copyright text here. Appears in Footer attribution.', 'wecodeart' ),
				'priority'		=> 5,
				'sanitize_callback'	=> 'sanitize_text_field', 
				'transport'		=> 'postMessage',
				'partial'		=> [
					'selector'        => '.attribution__copyright',
					'render_callback' => [ 'WeCodeArt\Customizer\Partials', '_render_footer_copyright' ]
				]	
			)
		);

		return array_merge( $configurations, $_configs );
	}
}
