<?php 
/**
 * WeCodeArt Framework Init.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework.
 * @subpackage  Init
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		1.0
 * @version		3.8.5
 */

if ( ! defined( 'ABSPATH' ) ) exit();

use WeCodeArt\Activation;
use WeCodeArt\Customizer;
use WeCodeArt\Support;
use WeCodeArt\Core\Header;
use WeCodeArt\Core\Content;
use WeCodeArt\Core\Archive;
use WeCodeArt\Core\Entry;
use WeCodeArt\Core\Pagination;
use WeCodeArt\Core\Footer;
use WeCodeArt\Core\Comments;
use WeCodeArt\Core\Hooks;
use WeCodeArt\Core\Scripts;
use WeCodeArt\Admin;

// Include the autoloader.
require_once( get_parent_theme_file_path( '/inc/class-autoloader.php' ) );
new WeCodeArt\Autoloader();

/**
 * Final Class
 */
final class WeCodeArt {

	use \WeCodeArt\Singleton; 

	/**
	 * Theme Data
	 *
	 * @access	private
	 * @var 	object
	 */
	private static $theme_data; 

	/**
	 * Send to Constructor
	 * @since 3.6.2
	 */
	public function init() {
		// Can we proceed with theme activation/loading?
		if( Activation::get_instance()->is_ok() ) {
			$this->load();
		}
	}

	/**
	 * Load Theme Modules
	 *
	 * @since 3.6.2
	 */
	public function load() {
		self::$theme_data = wp_get_theme( null );

		// Fire Core Classes
		Header		::get_instance();
		Content		::get_instance();
		Archive		::get_instance();
		Entry		::get_instance();
		Comments	::get_instance();
		Pagination	::get_instance();
		Footer		::get_instance();
		Scripts		::get_instance();
		Hooks		::get_instance();

		// Admin Stuff
		Admin 		::get_instance();
		Customizer 	::get_instance();

		// Fire Support Class
		Support		::get_instance();
	}
	
	/**
	 * Render the layout
	 *
	 * @since 3.8.1
	 */
	public static function layout() {
		/**
		 * @see - https://developer.wordpress.org/reference/functions/get_header/
		 */
		get_header();

		/**
		 * @see - WeCodeArt\Core\Content::render_modules();
		 */
		do_action( 'wecodeart_inner_markup' );

		/**
		 * @see - https://developer.wordpress.org/reference/functions/get_footer/
		 */
		get_footer();
	}
}

/**
 * Init the Framework
 */
WeCodeArt::get_instance();

/**
 * Puts Everything togheter
 *
 * @since	1.0
 * @version	3.8.1
 *
 * @return	mixed 	Site Layout
 */
function wecodeart() {	
	WeCodeArt::layout(); 
}